# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/type/matcher/regex.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/type/matcher/regex.proto',
  package='envoy.type.matcher',
  syntax='proto3',
  serialized_options=b'\n io.envoyproxy.envoy.type.matcherB\nRegexProtoP\001\272\200\310\321\006\002\020\001',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x1e\x65nvoy/type/matcher/regex.proto\x12\x12\x65nvoy.type.matcher\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"\xcf\x01\n\x0cRegexMatcher\x12J\n\ngoogle_re2\x18\x01 \x01(\x0b\x32*.envoy.type.matcher.RegexMatcher.GoogleRE2B\x08\xfa\x42\x05\x8a\x01\x02\x10\x01H\x00\x12\x16\n\x05regex\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x1aG\n\tGoogleRE2\x12:\n\x10max_program_size\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueB\x02\x18\x01\x42\x12\n\x0b\x65ngine_type\x12\x03\xf8\x42\x01\"b\n\x17RegexMatchAndSubstitute\x12\x31\n\x07pattern\x18\x01 \x01(\x0b\x32 .envoy.type.matcher.RegexMatcher\x12\x14\n\x0csubstitution\x18\x02 \x01(\tB8\n io.envoyproxy.envoy.type.matcherB\nRegexProtoP\x01\xba\x80\xc8\xd1\x06\x02\x10\x01\x62\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,validate_dot_validate__pb2.DESCRIPTOR,])




_REGEXMATCHER_GOOGLERE2 = _descriptor.Descriptor(
  name='GoogleRE2',
  full_name='envoy.type.matcher.RegexMatcher.GoogleRE2',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='max_program_size', full_name='envoy.type.matcher.RegexMatcher.GoogleRE2.max_program_size', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\030\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=259,
  serialized_end=330,
)

_REGEXMATCHER = _descriptor.Descriptor(
  name='RegexMatcher',
  full_name='envoy.type.matcher.RegexMatcher',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='google_re2', full_name='envoy.type.matcher.RegexMatcher.google_re2', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\212\001\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='regex', full_name='envoy.type.matcher.RegexMatcher.regex', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004r\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_REGEXMATCHER_GOOGLERE2, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='engine_type', full_name='envoy.type.matcher.RegexMatcher.engine_type',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[], serialized_options=b'\370B\001'),
  ],
  serialized_start=143,
  serialized_end=350,
)


_REGEXMATCHANDSUBSTITUTE = _descriptor.Descriptor(
  name='RegexMatchAndSubstitute',
  full_name='envoy.type.matcher.RegexMatchAndSubstitute',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='pattern', full_name='envoy.type.matcher.RegexMatchAndSubstitute.pattern', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='substitution', full_name='envoy.type.matcher.RegexMatchAndSubstitute.substitution', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=352,
  serialized_end=450,
)

_REGEXMATCHER_GOOGLERE2.fields_by_name['max_program_size'].message_type = google_dot_protobuf_dot_wrappers__pb2._UINT32VALUE
_REGEXMATCHER_GOOGLERE2.containing_type = _REGEXMATCHER
_REGEXMATCHER.fields_by_name['google_re2'].message_type = _REGEXMATCHER_GOOGLERE2
_REGEXMATCHER.oneofs_by_name['engine_type'].fields.append(
  _REGEXMATCHER.fields_by_name['google_re2'])
_REGEXMATCHER.fields_by_name['google_re2'].containing_oneof = _REGEXMATCHER.oneofs_by_name['engine_type']
_REGEXMATCHANDSUBSTITUTE.fields_by_name['pattern'].message_type = _REGEXMATCHER
DESCRIPTOR.message_types_by_name['RegexMatcher'] = _REGEXMATCHER
DESCRIPTOR.message_types_by_name['RegexMatchAndSubstitute'] = _REGEXMATCHANDSUBSTITUTE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

RegexMatcher = _reflection.GeneratedProtocolMessageType('RegexMatcher', (_message.Message,), {

  'GoogleRE2' : _reflection.GeneratedProtocolMessageType('GoogleRE2', (_message.Message,), {
    'DESCRIPTOR' : _REGEXMATCHER_GOOGLERE2,
    '__module__' : 'envoy.type.matcher.regex_pb2'
    # @@protoc_insertion_point(class_scope:envoy.type.matcher.RegexMatcher.GoogleRE2)
    })
  ,
  'DESCRIPTOR' : _REGEXMATCHER,
  '__module__' : 'envoy.type.matcher.regex_pb2'
  # @@protoc_insertion_point(class_scope:envoy.type.matcher.RegexMatcher)
  })
_sym_db.RegisterMessage(RegexMatcher)
_sym_db.RegisterMessage(RegexMatcher.GoogleRE2)

RegexMatchAndSubstitute = _reflection.GeneratedProtocolMessageType('RegexMatchAndSubstitute', (_message.Message,), {
  'DESCRIPTOR' : _REGEXMATCHANDSUBSTITUTE,
  '__module__' : 'envoy.type.matcher.regex_pb2'
  # @@protoc_insertion_point(class_scope:envoy.type.matcher.RegexMatchAndSubstitute)
  })
_sym_db.RegisterMessage(RegexMatchAndSubstitute)


DESCRIPTOR._options = None
_REGEXMATCHER_GOOGLERE2.fields_by_name['max_program_size']._options = None
_REGEXMATCHER.oneofs_by_name['engine_type']._options = None
_REGEXMATCHER.fields_by_name['google_re2']._options = None
_REGEXMATCHER.fields_by_name['regex']._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/api/v2/auth/common.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.api.v2.core import base_pb2 as envoy_dot_api_dot_v2_dot_core_dot_base__pb2
try:
  envoy_dot_api_dot_v2_dot_core_dot_socket__option__pb2 = envoy_dot_api_dot_v2_dot_core_dot_base__pb2.envoy_dot_api_dot_v2_dot_core_dot_socket__option__pb2
except AttributeError:
  envoy_dot_api_dot_v2_dot_core_dot_socket__option__pb2 = envoy_dot_api_dot_v2_dot_core_dot_base__pb2.envoy.api.v2.core.socket_option_pb2
from envoy.type.matcher import string_pb2 as envoy_dot_type_dot_matcher_dot_string__pb2
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from udpa.annotations import migrate_pb2 as udpa_dot_annotations_dot_migrate__pb2
from udpa.annotations import sensitive_pb2 as udpa_dot_annotations_dot_sensitive__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/api/v2/auth/common.proto',
  package='envoy.api.v2.auth',
  syntax='proto3',
  serialized_options=b'\n\037io.envoyproxy.envoy.api.v2.authB\013CommonProtoP\001\362\230\376\217\005+\022)envoy.extensions.transport_sockets.tls.v3\272\200\310\321\006\002\020\001',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x1e\x65nvoy/api/v2/auth/common.proto\x12\x11\x65nvoy.api.v2.auth\x1a\x1c\x65nvoy/api/v2/core/base.proto\x1a\x1f\x65nvoy/type/matcher/string.proto\x1a\x19google/protobuf/any.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1eudpa/annotations/migrate.proto\x1a udpa/annotations/sensitive.proto\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"\xc8\x02\n\rTlsParameters\x12\\\n\x1ctls_minimum_protocol_version\x18\x01 \x01(\x0e\x32,.envoy.api.v2.auth.TlsParameters.TlsProtocolB\x08\xfa\x42\x05\x82\x01\x02\x10\x01\x12\\\n\x1ctls_maximum_protocol_version\x18\x02 \x01(\x0e\x32,.envoy.api.v2.auth.TlsParameters.TlsProtocolB\x08\xfa\x42\x05\x82\x01\x02\x10\x01\x12\x15\n\rcipher_suites\x18\x03 \x03(\t\x12\x13\n\x0b\x65\x63\x64h_curves\x18\x04 \x03(\t\"O\n\x0bTlsProtocol\x12\x0c\n\x08TLS_AUTO\x10\x00\x12\x0b\n\x07TLSv1_0\x10\x01\x12\x0b\n\x07TLSv1_1\x10\x02\x12\x0b\n\x07TLSv1_2\x10\x03\x12\x0b\n\x07TLSv1_3\x10\x04\"\xae\x01\n\x12PrivateKeyProvider\x12\x1e\n\rprovider_name\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02 \x01\x12\x33\n\x06\x63onfig\x18\x02 \x01(\x0b\x32\x17.google.protobuf.StructB\x08\x18\x01\xb8\xb7\x8b\xa4\x02\x01H\x00\x12\x34\n\x0ctyped_config\x18\x03 \x01(\x0b\x32\x14.google.protobuf.AnyB\x06\xb8\xb7\x8b\xa4\x02\x01H\x00\x42\r\n\x0b\x63onfig_type\"\xfd\x02\n\x0eTlsCertificate\x12\x38\n\x11\x63\x65rtificate_chain\x18\x01 \x01(\x0b\x32\x1d.envoy.api.v2.core.DataSource\x12:\n\x0bprivate_key\x18\x02 \x01(\x0b\x32\x1d.envoy.api.v2.core.DataSourceB\x06\xb8\xb7\x8b\xa4\x02\x01\x12\x43\n\x14private_key_provider\x18\x06 \x01(\x0b\x32%.envoy.api.v2.auth.PrivateKeyProvider\x12\x37\n\x08password\x18\x03 \x01(\x0b\x32\x1d.envoy.api.v2.core.DataSourceB\x06\xb8\xb7\x8b\xa4\x02\x01\x12\x32\n\x0bocsp_staple\x18\x04 \x01(\x0b\x32\x1d.envoy.api.v2.core.DataSource\x12\x43\n\x1csigned_certificate_timestamp\x18\x05 \x03(\x0b\x32\x1d.envoy.api.v2.core.DataSource\"S\n\x14TlsSessionTicketKeys\x12;\n\x04keys\x18\x01 \x03(\x0b\x32\x1d.envoy.api.v2.core.DataSourceB\x0e\xfa\x42\x05\x92\x01\x02\x08\x01\xb8\xb7\x8b\xa4\x02\x01\"\xaa\x05\n\x1c\x43\x65rtificateValidationContext\x12\x31\n\ntrusted_ca\x18\x01 \x01(\x0b\x32\x1d.envoy.api.v2.core.DataSource\x12/\n\x17verify_certificate_spki\x18\x03 \x03(\tB\x0e\xfa\x42\x0b\x92\x01\x08\"\x06r\x04 ,(,\x12/\n\x17verify_certificate_hash\x18\x02 \x03(\tB\x0e\xfa\x42\x0b\x92\x01\x08\"\x06r\x04 @(_\x12#\n\x17verify_subject_alt_name\x18\x04 \x03(\tB\x02\x18\x01\x12\x42\n\x17match_subject_alt_names\x18\t \x03(\x0b\x32!.envoy.type.matcher.StringMatcher\x12\x37\n\x13require_ocsp_staple\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12H\n$require_signed_certificate_timestamp\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12*\n\x03\x63rl\x18\x07 \x01(\x0b\x32\x1d.envoy.api.v2.core.DataSource\x12!\n\x19\x61llow_expired_certificate\x18\x08 \x01(\x08\x12r\n\x18trust_chain_verification\x18\n \x01(\x0e\x32\x46.envoy.api.v2.auth.CertificateValidationContext.TrustChainVerificationB\x08\xfa\x42\x05\x82\x01\x02\x10\x01\"F\n\x16TrustChainVerification\x12\x16\n\x12VERIFY_TRUST_CHAIN\x10\x00\x12\x14\n\x10\x41\x43\x43\x45PT_UNTRUSTED\x10\x01\x42i\n\x1fio.envoyproxy.envoy.api.v2.authB\x0b\x43ommonProtoP\x01\xf2\x98\xfe\x8f\x05+\x12)envoy.extensions.transport_sockets.tls.v3\xba\x80\xc8\xd1\x06\x02\x10\x01\x62\x06proto3'
  ,
  dependencies=[envoy_dot_api_dot_v2_dot_core_dot_base__pb2.DESCRIPTOR,envoy_dot_type_dot_matcher_dot_string__pb2.DESCRIPTOR,google_dot_protobuf_dot_any__pb2.DESCRIPTOR,google_dot_protobuf_dot_struct__pb2.DESCRIPTOR,google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,udpa_dot_annotations_dot_migrate__pb2.DESCRIPTOR,udpa_dot_annotations_dot_sensitive__pb2.DESCRIPTOR,udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,validate_dot_validate__pb2.DESCRIPTOR,])



_TLSPARAMETERS_TLSPROTOCOL = _descriptor.EnumDescriptor(
  name='TlsProtocol',
  full_name='envoy.api.v2.auth.TlsParameters.TlsProtocol',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='TLS_AUTO', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TLSv1_0', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TLSv1_1', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TLSv1_2', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TLSv1_3', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=577,
  serialized_end=656,
)
_sym_db.RegisterEnumDescriptor(_TLSPARAMETERS_TLSPROTOCOL)

_CERTIFICATEVALIDATIONCONTEXT_TRUSTCHAINVERIFICATION = _descriptor.EnumDescriptor(
  name='TrustChainVerification',
  full_name='envoy.api.v2.auth.CertificateValidationContext.TrustChainVerification',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='VERIFY_TRUST_CHAIN', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ACCEPT_UNTRUSTED', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1917,
  serialized_end=1987,
)
_sym_db.RegisterEnumDescriptor(_CERTIFICATEVALIDATIONCONTEXT_TRUSTCHAINVERIFICATION)


_TLSPARAMETERS = _descriptor.Descriptor(
  name='TlsParameters',
  full_name='envoy.api.v2.auth.TlsParameters',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='tls_minimum_protocol_version', full_name='envoy.api.v2.auth.TlsParameters.tls_minimum_protocol_version', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\202\001\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tls_maximum_protocol_version', full_name='envoy.api.v2.auth.TlsParameters.tls_maximum_protocol_version', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\202\001\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cipher_suites', full_name='envoy.api.v2.auth.TlsParameters.cipher_suites', index=2,
      number=3, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ecdh_curves', full_name='envoy.api.v2.auth.TlsParameters.ecdh_curves', index=3,
      number=4, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _TLSPARAMETERS_TLSPROTOCOL,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=328,
  serialized_end=656,
)


_PRIVATEKEYPROVIDER = _descriptor.Descriptor(
  name='PrivateKeyProvider',
  full_name='envoy.api.v2.auth.PrivateKeyProvider',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='provider_name', full_name='envoy.api.v2.auth.PrivateKeyProvider.provider_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004r\002 \001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='config', full_name='envoy.api.v2.auth.PrivateKeyProvider.config', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\030\001\270\267\213\244\002\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='typed_config', full_name='envoy.api.v2.auth.PrivateKeyProvider.typed_config', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\270\267\213\244\002\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='config_type', full_name='envoy.api.v2.auth.PrivateKeyProvider.config_type',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=659,
  serialized_end=833,
)


_TLSCERTIFICATE = _descriptor.Descriptor(
  name='TlsCertificate',
  full_name='envoy.api.v2.auth.TlsCertificate',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='certificate_chain', full_name='envoy.api.v2.auth.TlsCertificate.certificate_chain', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='private_key', full_name='envoy.api.v2.auth.TlsCertificate.private_key', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\270\267\213\244\002\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='private_key_provider', full_name='envoy.api.v2.auth.TlsCertificate.private_key_provider', index=2,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='password', full_name='envoy.api.v2.auth.TlsCertificate.password', index=3,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\270\267\213\244\002\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ocsp_staple', full_name='envoy.api.v2.auth.TlsCertificate.ocsp_staple', index=4,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='signed_certificate_timestamp', full_name='envoy.api.v2.auth.TlsCertificate.signed_certificate_timestamp', index=5,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=836,
  serialized_end=1217,
)


_TLSSESSIONTICKETKEYS = _descriptor.Descriptor(
  name='TlsSessionTicketKeys',
  full_name='envoy.api.v2.auth.TlsSessionTicketKeys',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='keys', full_name='envoy.api.v2.auth.TlsSessionTicketKeys.keys', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\222\001\002\010\001\270\267\213\244\002\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1219,
  serialized_end=1302,
)


_CERTIFICATEVALIDATIONCONTEXT = _descriptor.Descriptor(
  name='CertificateValidationContext',
  full_name='envoy.api.v2.auth.CertificateValidationContext',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='trusted_ca', full_name='envoy.api.v2.auth.CertificateValidationContext.trusted_ca', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='verify_certificate_spki', full_name='envoy.api.v2.auth.CertificateValidationContext.verify_certificate_spki', index=1,
      number=3, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\013\222\001\010\"\006r\004 ,(,', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='verify_certificate_hash', full_name='envoy.api.v2.auth.CertificateValidationContext.verify_certificate_hash', index=2,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\013\222\001\010\"\006r\004 @(_', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='verify_subject_alt_name', full_name='envoy.api.v2.auth.CertificateValidationContext.verify_subject_alt_name', index=3,
      number=4, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\030\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='match_subject_alt_names', full_name='envoy.api.v2.auth.CertificateValidationContext.match_subject_alt_names', index=4,
      number=9, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='require_ocsp_staple', full_name='envoy.api.v2.auth.CertificateValidationContext.require_ocsp_staple', index=5,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='require_signed_certificate_timestamp', full_name='envoy.api.v2.auth.CertificateValidationContext.require_signed_certificate_timestamp', index=6,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='crl', full_name='envoy.api.v2.auth.CertificateValidationContext.crl', index=7,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='allow_expired_certificate', full_name='envoy.api.v2.auth.CertificateValidationContext.allow_expired_certificate', index=8,
      number=8, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='trust_chain_verification', full_name='envoy.api.v2.auth.CertificateValidationContext.trust_chain_verification', index=9,
      number=10, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\202\001\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _CERTIFICATEVALIDATIONCONTEXT_TRUSTCHAINVERIFICATION,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1305,
  serialized_end=1987,
)

_TLSPARAMETERS.fields_by_name['tls_minimum_protocol_version'].enum_type = _TLSPARAMETERS_TLSPROTOCOL
_TLSPARAMETERS.fields_by_name['tls_maximum_protocol_version'].enum_type = _TLSPARAMETERS_TLSPROTOCOL
_TLSPARAMETERS_TLSPROTOCOL.containing_type = _TLSPARAMETERS
_PRIVATEKEYPROVIDER.fields_by_name['config'].message_type = google_dot_protobuf_dot_struct__pb2._STRUCT
_PRIVATEKEYPROVIDER.fields_by_name['typed_config'].message_type = google_dot_protobuf_dot_any__pb2._ANY
_PRIVATEKEYPROVIDER.oneofs_by_name['config_type'].fields.append(
  _PRIVATEKEYPROVIDER.fields_by_name['config'])
_PRIVATEKEYPROVIDER.fields_by_name['config'].containing_oneof = _PRIVATEKEYPROVIDER.oneofs_by_name['config_type']
_PRIVATEKEYPROVIDER.oneofs_by_name['config_type'].fields.append(
  _PRIVATEKEYPROVIDER.fields_by_name['typed_config'])
_PRIVATEKEYPROVIDER.fields_by_name['typed_config'].containing_oneof = _PRIVATEKEYPROVIDER.oneofs_by_name['config_type']
_TLSCERTIFICATE.fields_by_name['certificate_chain'].message_type = envoy_dot_api_dot_v2_dot_core_dot_base__pb2._DATASOURCE
_TLSCERTIFICATE.fields_by_name['private_key'].message_type = envoy_dot_api_dot_v2_dot_core_dot_base__pb2._DATASOURCE
_TLSCERTIFICATE.fields_by_name['private_key_provider'].message_type = _PRIVATEKEYPROVIDER
_TLSCERTIFICATE.fields_by_name['password'].message_type = envoy_dot_api_dot_v2_dot_core_dot_base__pb2._DATASOURCE
_TLSCERTIFICATE.fields_by_name['ocsp_staple'].message_type = envoy_dot_api_dot_v2_dot_core_dot_base__pb2._DATASOURCE
_TLSCERTIFICATE.fields_by_name['signed_certificate_timestamp'].message_type = envoy_dot_api_dot_v2_dot_core_dot_base__pb2._DATASOURCE
_TLSSESSIONTICKETKEYS.fields_by_name['keys'].message_type = envoy_dot_api_dot_v2_dot_core_dot_base__pb2._DATASOURCE
_CERTIFICATEVALIDATIONCONTEXT.fields_by_name['trusted_ca'].message_type = envoy_dot_api_dot_v2_dot_core_dot_base__pb2._DATASOURCE
_CERTIFICATEVALIDATIONCONTEXT.fields_by_name['match_subject_alt_names'].message_type = envoy_dot_type_dot_matcher_dot_string__pb2._STRINGMATCHER
_CERTIFICATEVALIDATIONCONTEXT.fields_by_name['require_ocsp_staple'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_CERTIFICATEVALIDATIONCONTEXT.fields_by_name['require_signed_certificate_timestamp'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_CERTIFICATEVALIDATIONCONTEXT.fields_by_name['crl'].message_type = envoy_dot_api_dot_v2_dot_core_dot_base__pb2._DATASOURCE
_CERTIFICATEVALIDATIONCONTEXT.fields_by_name['trust_chain_verification'].enum_type = _CERTIFICATEVALIDATIONCONTEXT_TRUSTCHAINVERIFICATION
_CERTIFICATEVALIDATIONCONTEXT_TRUSTCHAINVERIFICATION.containing_type = _CERTIFICATEVALIDATIONCONTEXT
DESCRIPTOR.message_types_by_name['TlsParameters'] = _TLSPARAMETERS
DESCRIPTOR.message_types_by_name['PrivateKeyProvider'] = _PRIVATEKEYPROVIDER
DESCRIPTOR.message_types_by_name['TlsCertificate'] = _TLSCERTIFICATE
DESCRIPTOR.message_types_by_name['TlsSessionTicketKeys'] = _TLSSESSIONTICKETKEYS
DESCRIPTOR.message_types_by_name['CertificateValidationContext'] = _CERTIFICATEVALIDATIONCONTEXT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

TlsParameters = _reflection.GeneratedProtocolMessageType('TlsParameters', (_message.Message,), {
  'DESCRIPTOR' : _TLSPARAMETERS,
  '__module__' : 'envoy.api.v2.auth.common_pb2'
  # @@protoc_insertion_point(class_scope:envoy.api.v2.auth.TlsParameters)
  })
_sym_db.RegisterMessage(TlsParameters)

PrivateKeyProvider = _reflection.GeneratedProtocolMessageType('PrivateKeyProvider', (_message.Message,), {
  'DESCRIPTOR' : _PRIVATEKEYPROVIDER,
  '__module__' : 'envoy.api.v2.auth.common_pb2'
  # @@protoc_insertion_point(class_scope:envoy.api.v2.auth.PrivateKeyProvider)
  })
_sym_db.RegisterMessage(PrivateKeyProvider)

TlsCertificate = _reflection.GeneratedProtocolMessageType('TlsCertificate', (_message.Message,), {
  'DESCRIPTOR' : _TLSCERTIFICATE,
  '__module__' : 'envoy.api.v2.auth.common_pb2'
  # @@protoc_insertion_point(class_scope:envoy.api.v2.auth.TlsCertificate)
  })
_sym_db.RegisterMessage(TlsCertificate)

TlsSessionTicketKeys = _reflection.GeneratedProtocolMessageType('TlsSessionTicketKeys', (_message.Message,), {
  'DESCRIPTOR' : _TLSSESSIONTICKETKEYS,
  '__module__' : 'envoy.api.v2.auth.common_pb2'
  # @@protoc_insertion_point(class_scope:envoy.api.v2.auth.TlsSessionTicketKeys)
  })
_sym_db.RegisterMessage(TlsSessionTicketKeys)

CertificateValidationContext = _reflection.GeneratedProtocolMessageType('CertificateValidationContext', (_message.Message,), {
  'DESCRIPTOR' : _CERTIFICATEVALIDATIONCONTEXT,
  '__module__' : 'envoy.api.v2.auth.common_pb2'
  # @@protoc_insertion_point(class_scope:envoy.api.v2.auth.CertificateValidationContext)
  })
_sym_db.RegisterMessage(CertificateValidationContext)


DESCRIPTOR._options = None
_TLSPARAMETERS.fields_by_name['tls_minimum_protocol_version']._options = None
_TLSPARAMETERS.fields_by_name['tls_maximum_protocol_version']._options = None
_PRIVATEKEYPROVIDER.fields_by_name['provider_name']._options = None
_PRIVATEKEYPROVIDER.fields_by_name['config']._options = None
_PRIVATEKEYPROVIDER.fields_by_name['typed_config']._options = None
_TLSCERTIFICATE.fields_by_name['private_key']._options = None
_TLSCERTIFICATE.fields_by_name['password']._options = None
_TLSSESSIONTICKETKEYS.fields_by_name['keys']._options = None
_CERTIFICATEVALIDATIONCONTEXT.fields_by_name['verify_certificate_spki']._options = None
_CERTIFICATEVALIDATIONCONTEXT.fields_by_name['verify_certificate_hash']._options = None
_CERTIFICATEVALIDATIONCONTEXT.fields_by_name['verify_subject_alt_name']._options = None
_CERTIFICATEVALIDATIONCONTEXT.fields_by_name['trust_chain_verification']._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/extensions/filters/network/wasm/v3/wasm.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.extensions.wasm.v3 import wasm_pb2 as envoy_dot_extensions_dot_wasm_dot_v3_dot_wasm__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/extensions/filters/network/wasm/v3/wasm.proto',
  package='envoy.extensions.filters.network.wasm.v3',
  syntax='proto3',
  serialized_options=b'\n6io.envoyproxy.envoy.extensions.filters.network.wasm.v3B\tWasmProtoP\001\272\200\310\321\006\002\020\002',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n3envoy/extensions/filters/network/wasm/v3/wasm.proto\x12(envoy.extensions.filters.network.wasm.v3\x1a#envoy/extensions/wasm/v3/wasm.proto\x1a\x1dudpa/annotations/status.proto\">\n\x04Wasm\x12\x36\n\x06\x63onfig\x18\x01 \x01(\x0b\x32&.envoy.extensions.wasm.v3.PluginConfigBM\n6io.envoyproxy.envoy.extensions.filters.network.wasm.v3B\tWasmProtoP\x01\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3'
  ,
  dependencies=[envoy_dot_extensions_dot_wasm_dot_v3_dot_wasm__pb2.DESCRIPTOR,udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,])




_WASM = _descriptor.Descriptor(
  name='Wasm',
  full_name='envoy.extensions.filters.network.wasm.v3.Wasm',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='config', full_name='envoy.extensions.filters.network.wasm.v3.Wasm.config', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=165,
  serialized_end=227,
)

_WASM.fields_by_name['config'].message_type = envoy_dot_extensions_dot_wasm_dot_v3_dot_wasm__pb2._PLUGINCONFIG
DESCRIPTOR.message_types_by_name['Wasm'] = _WASM
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Wasm = _reflection.GeneratedProtocolMessageType('Wasm', (_message.Message,), {
  'DESCRIPTOR' : _WASM,
  '__module__' : 'envoy.extensions.filters.network.wasm.v3.wasm_pb2'
  # @@protoc_insertion_point(class_scope:envoy.extensions.filters.network.wasm.v3.Wasm)
  })
_sym_db.RegisterMessage(Wasm)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/config/cluster/v4alpha/circuit_breaker.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.config.core.v4alpha import base_pb2 as envoy_dot_config_dot_core_dot_v4alpha_dot_base__pb2
from envoy.type.v3 import percent_pb2 as envoy_dot_type_dot_v3_dot_percent__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from udpa.annotations import versioning_pb2 as udpa_dot_annotations_dot_versioning__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/config/cluster/v4alpha/circuit_breaker.proto',
  package='envoy.config.cluster.v4alpha',
  syntax='proto3',
  serialized_options=b'\n*io.envoyproxy.envoy.config.cluster.v4alphaB\023CircuitBreakerProtoP\001\272\200\310\321\006\002\020\003',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n2envoy/config/cluster/v4alpha/circuit_breaker.proto\x12\x1c\x65nvoy.config.cluster.v4alpha\x1a$envoy/config/core/v4alpha/base.proto\x1a\x1b\x65nvoy/type/v3/percent.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1dudpa/annotations/status.proto\x1a!udpa/annotations/versioning.proto\x1a\x17validate/validate.proto\"\xf0\x06\n\x0f\x43ircuitBreakers\x12L\n\nthresholds\x18\x01 \x03(\x0b\x32\x38.envoy.config.cluster.v4alpha.CircuitBreakers.Thresholds\x1a\xde\x05\n\nThresholds\x12\x46\n\x08priority\x18\x01 \x01(\x0e\x32*.envoy.config.core.v4alpha.RoutingPriorityB\x08\xfa\x42\x05\x82\x01\x02\x10\x01\x12\x35\n\x0fmax_connections\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.UInt32Value\x12:\n\x14max_pending_requests\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.UInt32Value\x12\x32\n\x0cmax_requests\x18\x04 \x01(\x0b\x32\x1c.google.protobuf.UInt32Value\x12\x31\n\x0bmax_retries\x18\x05 \x01(\x0b\x32\x1c.google.protobuf.UInt32Value\x12Z\n\x0cretry_budget\x18\x08 \x01(\x0b\x32\x44.envoy.config.cluster.v4alpha.CircuitBreakers.Thresholds.RetryBudget\x12\x17\n\x0ftrack_remaining\x18\x06 \x01(\x08\x12:\n\x14max_connection_pools\x18\x07 \x01(\x0b\x32\x1c.google.protobuf.UInt32Value\x1a\xc1\x01\n\x0bRetryBudget\x12.\n\x0e\x62udget_percent\x18\x01 \x01(\x0b\x32\x16.envoy.type.v3.Percent\x12;\n\x15min_retry_concurrency\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.UInt32Value:E\x9a\xc5\x88\x1e@\n>envoy.config.cluster.v3.CircuitBreakers.Thresholds.RetryBudget:9\x9a\xc5\x88\x1e\x34\n2envoy.config.cluster.v3.CircuitBreakers.Thresholds:.\x9a\xc5\x88\x1e)\n\'envoy.config.cluster.v3.CircuitBreakersBK\n*io.envoyproxy.envoy.config.cluster.v4alphaB\x13\x43ircuitBreakerProtoP\x01\xba\x80\xc8\xd1\x06\x02\x10\x03\x62\x06proto3'
  ,
  dependencies=[envoy_dot_config_dot_core_dot_v4alpha_dot_base__pb2.DESCRIPTOR,envoy_dot_type_dot_v3_dot_percent__pb2.DESCRIPTOR,google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,udpa_dot_annotations_dot_versioning__pb2.DESCRIPTOR,validate_dot_validate__pb2.DESCRIPTOR,])




_CIRCUITBREAKERS_THRESHOLDS_RETRYBUDGET = _descriptor.Descriptor(
  name='RetryBudget',
  full_name='envoy.config.cluster.v4alpha.CircuitBreakers.Thresholds.RetryBudget',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='budget_percent', full_name='envoy.config.cluster.v4alpha.CircuitBreakers.Thresholds.RetryBudget.budget_percent', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='min_retry_concurrency', full_name='envoy.config.cluster.v4alpha.CircuitBreakers.Thresholds.RetryBudget.min_retry_concurrency', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036@\n>envoy.config.cluster.v3.CircuitBreakers.Thresholds.RetryBudget',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=855,
  serialized_end=1048,
)

_CIRCUITBREAKERS_THRESHOLDS = _descriptor.Descriptor(
  name='Thresholds',
  full_name='envoy.config.cluster.v4alpha.CircuitBreakers.Thresholds',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='priority', full_name='envoy.config.cluster.v4alpha.CircuitBreakers.Thresholds.priority', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\202\001\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_connections', full_name='envoy.config.cluster.v4alpha.CircuitBreakers.Thresholds.max_connections', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_pending_requests', full_name='envoy.config.cluster.v4alpha.CircuitBreakers.Thresholds.max_pending_requests', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_requests', full_name='envoy.config.cluster.v4alpha.CircuitBreakers.Thresholds.max_requests', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_retries', full_name='envoy.config.cluster.v4alpha.CircuitBreakers.Thresholds.max_retries', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='retry_budget', full_name='envoy.config.cluster.v4alpha.CircuitBreakers.Thresholds.retry_budget', index=5,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='track_remaining', full_name='envoy.config.cluster.v4alpha.CircuitBreakers.Thresholds.track_remaining', index=6,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_connection_pools', full_name='envoy.config.cluster.v4alpha.CircuitBreakers.Thresholds.max_connection_pools', index=7,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_CIRCUITBREAKERS_THRESHOLDS_RETRYBUDGET, ],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\0364\n2envoy.config.cluster.v3.CircuitBreakers.Thresholds',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=373,
  serialized_end=1107,
)

_CIRCUITBREAKERS = _descriptor.Descriptor(
  name='CircuitBreakers',
  full_name='envoy.config.cluster.v4alpha.CircuitBreakers',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='thresholds', full_name='envoy.config.cluster.v4alpha.CircuitBreakers.thresholds', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_CIRCUITBREAKERS_THRESHOLDS, ],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036)\n\'envoy.config.cluster.v3.CircuitBreakers',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=275,
  serialized_end=1155,
)

_CIRCUITBREAKERS_THRESHOLDS_RETRYBUDGET.fields_by_name['budget_percent'].message_type = envoy_dot_type_dot_v3_dot_percent__pb2._PERCENT
_CIRCUITBREAKERS_THRESHOLDS_RETRYBUDGET.fields_by_name['min_retry_concurrency'].message_type = google_dot_protobuf_dot_wrappers__pb2._UINT32VALUE
_CIRCUITBREAKERS_THRESHOLDS_RETRYBUDGET.containing_type = _CIRCUITBREAKERS_THRESHOLDS
_CIRCUITBREAKERS_THRESHOLDS.fields_by_name['priority'].enum_type = envoy_dot_config_dot_core_dot_v4alpha_dot_base__pb2._ROUTINGPRIORITY
_CIRCUITBREAKERS_THRESHOLDS.fields_by_name['max_connections'].message_type = google_dot_protobuf_dot_wrappers__pb2._UINT32VALUE
_CIRCUITBREAKERS_THRESHOLDS.fields_by_name['max_pending_requests'].message_type = google_dot_protobuf_dot_wrappers__pb2._UINT32VALUE
_CIRCUITBREAKERS_THRESHOLDS.fields_by_name['max_requests'].message_type = google_dot_protobuf_dot_wrappers__pb2._UINT32VALUE
_CIRCUITBREAKERS_THRESHOLDS.fields_by_name['max_retries'].message_type = google_dot_protobuf_dot_wrappers__pb2._UINT32VALUE
_CIRCUITBREAKERS_THRESHOLDS.fields_by_name['retry_budget'].message_type = _CIRCUITBREAKERS_THRESHOLDS_RETRYBUDGET
_CIRCUITBREAKERS_THRESHOLDS.fields_by_name['max_connection_pools'].message_type = google_dot_protobuf_dot_wrappers__pb2._UINT32VALUE
_CIRCUITBREAKERS_THRESHOLDS.containing_type = _CIRCUITBREAKERS
_CIRCUITBREAKERS.fields_by_name['thresholds'].message_type = _CIRCUITBREAKERS_THRESHOLDS
DESCRIPTOR.message_types_by_name['CircuitBreakers'] = _CIRCUITBREAKERS
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

CircuitBreakers = _reflection.GeneratedProtocolMessageType('CircuitBreakers', (_message.Message,), {

  'Thresholds' : _reflection.GeneratedProtocolMessageType('Thresholds', (_message.Message,), {

    'RetryBudget' : _reflection.GeneratedProtocolMessageType('RetryBudget', (_message.Message,), {
      'DESCRIPTOR' : _CIRCUITBREAKERS_THRESHOLDS_RETRYBUDGET,
      '__module__' : 'envoy.config.cluster.v4alpha.circuit_breaker_pb2'
      # @@protoc_insertion_point(class_scope:envoy.config.cluster.v4alpha.CircuitBreakers.Thresholds.RetryBudget)
      })
    ,
    'DESCRIPTOR' : _CIRCUITBREAKERS_THRESHOLDS,
    '__module__' : 'envoy.config.cluster.v4alpha.circuit_breaker_pb2'
    # @@protoc_insertion_point(class_scope:envoy.config.cluster.v4alpha.CircuitBreakers.Thresholds)
    })
  ,
  'DESCRIPTOR' : _CIRCUITBREAKERS,
  '__module__' : 'envoy.config.cluster.v4alpha.circuit_breaker_pb2'
  # @@protoc_insertion_point(class_scope:envoy.config.cluster.v4alpha.CircuitBreakers)
  })
_sym_db.RegisterMessage(CircuitBreakers)
_sym_db.RegisterMessage(CircuitBreakers.Thresholds)
_sym_db.RegisterMessage(CircuitBreakers.Thresholds.RetryBudget)


DESCRIPTOR._options = None
_CIRCUITBREAKERS_THRESHOLDS_RETRYBUDGET._options = None
_CIRCUITBREAKERS_THRESHOLDS.fields_by_name['priority']._options = None
_CIRCUITBREAKERS_THRESHOLDS._options = None
_CIRCUITBREAKERS._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: opencensus/proto/trace/v1/trace.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from opencensus.proto.resource.v1 import resource_pb2 as opencensus_dot_proto_dot_resource_dot_v1_dot_resource__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='opencensus/proto/trace/v1/trace.proto',
  package='opencensus.proto.trace.v1',
  syntax='proto3',
  serialized_options=b'\n\034io.opencensus.proto.trace.v1B\nTraceProtoP\001ZBgithub.com/census-instrumentation/opencensus-proto/gen-go/trace/v1\352\002\031OpenCensus.Proto.Trace.V1',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n%opencensus/proto/trace/v1/trace.proto\x12\x19opencensus.proto.trace.v1\x1a+opencensus/proto/resource/v1/resource.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1egoogle/protobuf/wrappers.proto\"\xac\x12\n\x04Span\x12\x10\n\x08trace_id\x18\x01 \x01(\x0c\x12\x0f\n\x07span_id\x18\x02 \x01(\x0c\x12>\n\ntracestate\x18\x0f \x01(\x0b\x32*.opencensus.proto.trace.v1.Span.Tracestate\x12\x16\n\x0eparent_span_id\x18\x03 \x01(\x0c\x12:\n\x04name\x18\x04 \x01(\x0b\x32,.opencensus.proto.trace.v1.TruncatableString\x12\x36\n\x04kind\x18\x0e \x01(\x0e\x32(.opencensus.proto.trace.v1.Span.SpanKind\x12.\n\nstart_time\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12,\n\x08\x65nd_time\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12>\n\nattributes\x18\x07 \x01(\x0b\x32*.opencensus.proto.trace.v1.Span.Attributes\x12:\n\x0bstack_trace\x18\x08 \x01(\x0b\x32%.opencensus.proto.trace.v1.StackTrace\x12?\n\x0btime_events\x18\t \x01(\x0b\x32*.opencensus.proto.trace.v1.Span.TimeEvents\x12\x34\n\x05links\x18\n \x01(\x0b\x32%.opencensus.proto.trace.v1.Span.Links\x12\x31\n\x06status\x18\x0b \x01(\x0b\x32!.opencensus.proto.trace.v1.Status\x12\x38\n\x08resource\x18\x10 \x01(\x0b\x32&.opencensus.proto.resource.v1.Resource\x12?\n\x1bsame_process_as_parent_span\x18\x0c \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x36\n\x10\x63hild_span_count\x18\r \x01(\x0b\x32\x1c.google.protobuf.UInt32Value\x1at\n\nTracestate\x12\x41\n\x07\x65ntries\x18\x01 \x03(\x0b\x32\x30.opencensus.proto.trace.v1.Span.Tracestate.Entry\x1a#\n\x05\x45ntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t\x1a\xe3\x01\n\nAttributes\x12S\n\rattribute_map\x18\x01 \x03(\x0b\x32<.opencensus.proto.trace.v1.Span.Attributes.AttributeMapEntry\x12 \n\x18\x64ropped_attributes_count\x18\x02 \x01(\x05\x1a^\n\x11\x41ttributeMapEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x38\n\x05value\x18\x02 \x01(\x0b\x32).opencensus.proto.trace.v1.AttributeValue:\x02\x38\x01\x1a\xbf\x04\n\tTimeEvent\x12(\n\x04time\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12J\n\nannotation\x18\x02 \x01(\x0b\x32\x34.opencensus.proto.trace.v1.Span.TimeEvent.AnnotationH\x00\x12O\n\rmessage_event\x18\x03 \x01(\x0b\x32\x36.opencensus.proto.trace.v1.Span.TimeEvent.MessageEventH\x00\x1a\x8f\x01\n\nAnnotation\x12\x41\n\x0b\x64\x65scription\x18\x01 \x01(\x0b\x32,.opencensus.proto.trace.v1.TruncatableString\x12>\n\nattributes\x18\x02 \x01(\x0b\x32*.opencensus.proto.trace.v1.Span.Attributes\x1a\xcf\x01\n\x0cMessageEvent\x12I\n\x04type\x18\x01 \x01(\x0e\x32;.opencensus.proto.trace.v1.Span.TimeEvent.MessageEvent.Type\x12\n\n\x02id\x18\x02 \x01(\x04\x12\x19\n\x11uncompressed_size\x18\x03 \x01(\x04\x12\x17\n\x0f\x63ompressed_size\x18\x04 \x01(\x04\"4\n\x04Type\x12\x14\n\x10TYPE_UNSPECIFIED\x10\x00\x12\x08\n\x04SENT\x10\x01\x12\x0c\n\x08RECEIVED\x10\x02\x42\x07\n\x05value\x1a\x94\x01\n\nTimeEvents\x12=\n\ntime_event\x18\x01 \x03(\x0b\x32).opencensus.proto.trace.v1.Span.TimeEvent\x12!\n\x19\x64ropped_annotations_count\x18\x02 \x01(\x05\x12$\n\x1c\x64ropped_message_events_count\x18\x03 \x01(\x05\x1a\xaf\x02\n\x04Link\x12\x10\n\x08trace_id\x18\x01 \x01(\x0c\x12\x0f\n\x07span_id\x18\x02 \x01(\x0c\x12\x37\n\x04type\x18\x03 \x01(\x0e\x32).opencensus.proto.trace.v1.Span.Link.Type\x12>\n\nattributes\x18\x04 \x01(\x0b\x32*.opencensus.proto.trace.v1.Span.Attributes\x12>\n\ntracestate\x18\x05 \x01(\x0b\x32*.opencensus.proto.trace.v1.Span.Tracestate\"K\n\x04Type\x12\x14\n\x10TYPE_UNSPECIFIED\x10\x00\x12\x15\n\x11\x43HILD_LINKED_SPAN\x10\x01\x12\x16\n\x12PARENT_LINKED_SPAN\x10\x02\x1aX\n\x05Links\x12\x32\n\x04link\x18\x01 \x03(\x0b\x32$.opencensus.proto.trace.v1.Span.Link\x12\x1b\n\x13\x64ropped_links_count\x18\x02 \x01(\x05\"=\n\x08SpanKind\x12\x19\n\x15SPAN_KIND_UNSPECIFIED\x10\x00\x12\n\n\x06SERVER\x10\x01\x12\n\n\x06\x43LIENT\x10\x02\"\'\n\x06Status\x12\x0c\n\x04\x63ode\x18\x01 \x01(\x05\x12\x0f\n\x07message\x18\x02 \x01(\t\"\xa2\x01\n\x0e\x41ttributeValue\x12\x44\n\x0cstring_value\x18\x01 \x01(\x0b\x32,.opencensus.proto.trace.v1.TruncatableStringH\x00\x12\x13\n\tint_value\x18\x02 \x01(\x03H\x00\x12\x14\n\nbool_value\x18\x03 \x01(\x08H\x00\x12\x16\n\x0c\x64ouble_value\x18\x04 \x01(\x01H\x00\x42\x07\n\x05value\"\xed\x04\n\nStackTrace\x12G\n\x0cstack_frames\x18\x01 \x01(\x0b\x32\x31.opencensus.proto.trace.v1.StackTrace.StackFrames\x12\x1b\n\x13stack_trace_hash_id\x18\x02 \x01(\x04\x1a\x8a\x03\n\nStackFrame\x12\x43\n\rfunction_name\x18\x01 \x01(\x0b\x32,.opencensus.proto.trace.v1.TruncatableString\x12L\n\x16original_function_name\x18\x02 \x01(\x0b\x32,.opencensus.proto.trace.v1.TruncatableString\x12?\n\tfile_name\x18\x03 \x01(\x0b\x32,.opencensus.proto.trace.v1.TruncatableString\x12\x13\n\x0bline_number\x18\x04 \x01(\x03\x12\x15\n\rcolumn_number\x18\x05 \x01(\x03\x12\x36\n\x0bload_module\x18\x06 \x01(\x0b\x32!.opencensus.proto.trace.v1.Module\x12\x44\n\x0esource_version\x18\x07 \x01(\x0b\x32,.opencensus.proto.trace.v1.TruncatableString\x1al\n\x0bStackFrames\x12?\n\x05\x66rame\x18\x01 \x03(\x0b\x32\x30.opencensus.proto.trace.v1.StackTrace.StackFrame\x12\x1c\n\x14\x64ropped_frames_count\x18\x02 \x01(\x05\"\x86\x01\n\x06Module\x12<\n\x06module\x18\x01 \x01(\x0b\x32,.opencensus.proto.trace.v1.TruncatableString\x12>\n\x08\x62uild_id\x18\x02 \x01(\x0b\x32,.opencensus.proto.trace.v1.TruncatableString\"@\n\x11TruncatableString\x12\r\n\x05value\x18\x01 \x01(\t\x12\x1c\n\x14truncated_byte_count\x18\x02 \x01(\x05\x42\x8c\x01\n\x1cio.opencensus.proto.trace.v1B\nTraceProtoP\x01ZBgithub.com/census-instrumentation/opencensus-proto/gen-go/trace/v1\xea\x02\x19OpenCensus.Proto.Trace.V1b\x06proto3'
  ,
  dependencies=[opencensus_dot_proto_dot_resource_dot_v1_dot_resource__pb2.DESCRIPTOR,google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,])



_SPAN_TIMEEVENT_MESSAGEEVENT_TYPE = _descriptor.EnumDescriptor(
  name='Type',
  full_name='opencensus.proto.trace.v1.Span.TimeEvent.MessageEvent.Type',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='TYPE_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SENT', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='RECEIVED', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1856,
  serialized_end=1908,
)
_sym_db.RegisterEnumDescriptor(_SPAN_TIMEEVENT_MESSAGEEVENT_TYPE)

_SPAN_LINK_TYPE = _descriptor.EnumDescriptor(
  name='Type',
  full_name='opencensus.proto.trace.v1.Span.Link.Type',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='TYPE_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CHILD_LINKED_SPAN', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PARENT_LINKED_SPAN', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=2299,
  serialized_end=2374,
)
_sym_db.RegisterEnumDescriptor(_SPAN_LINK_TYPE)

_SPAN_SPANKIND = _descriptor.EnumDescriptor(
  name='SpanKind',
  full_name='opencensus.proto.trace.v1.Span.SpanKind',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='SPAN_KIND_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SERVER', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CLIENT', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=2466,
  serialized_end=2527,
)
_sym_db.RegisterEnumDescriptor(_SPAN_SPANKIND)


_SPAN_TRACESTATE_ENTRY = _descriptor.Descriptor(
  name='Entry',
  full_name='opencensus.proto.trace.v1.Span.Tracestate.Entry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='opencensus.proto.trace.v1.Span.Tracestate.Entry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='opencensus.proto.trace.v1.Span.Tracestate.Entry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1074,
  serialized_end=1109,
)

_SPAN_TRACESTATE = _descriptor.Descriptor(
  name='Tracestate',
  full_name='opencensus.proto.trace.v1.Span.Tracestate',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='entries', full_name='opencensus.proto.trace.v1.Span.Tracestate.entries', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_SPAN_TRACESTATE_ENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=993,
  serialized_end=1109,
)

_SPAN_ATTRIBUTES_ATTRIBUTEMAPENTRY = _descriptor.Descriptor(
  name='AttributeMapEntry',
  full_name='opencensus.proto.trace.v1.Span.Attributes.AttributeMapEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='opencensus.proto.trace.v1.Span.Attributes.AttributeMapEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='opencensus.proto.trace.v1.Span.Attributes.AttributeMapEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1245,
  serialized_end=1339,
)

_SPAN_ATTRIBUTES = _descriptor.Descriptor(
  name='Attributes',
  full_name='opencensus.proto.trace.v1.Span.Attributes',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='attribute_map', full_name='opencensus.proto.trace.v1.Span.Attributes.attribute_map', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dropped_attributes_count', full_name='opencensus.proto.trace.v1.Span.Attributes.dropped_attributes_count', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_SPAN_ATTRIBUTES_ATTRIBUTEMAPENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1112,
  serialized_end=1339,
)

_SPAN_TIMEEVENT_ANNOTATION = _descriptor.Descriptor(
  name='Annotation',
  full_name='opencensus.proto.trace.v1.Span.TimeEvent.Annotation',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='description', full_name='opencensus.proto.trace.v1.Span.TimeEvent.Annotation.description', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='attributes', full_name='opencensus.proto.trace.v1.Span.TimeEvent.Annotation.attributes', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1555,
  serialized_end=1698,
)

_SPAN_TIMEEVENT_MESSAGEEVENT = _descriptor.Descriptor(
  name='MessageEvent',
  full_name='opencensus.proto.trace.v1.Span.TimeEvent.MessageEvent',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='opencensus.proto.trace.v1.Span.TimeEvent.MessageEvent.type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='id', full_name='opencensus.proto.trace.v1.Span.TimeEvent.MessageEvent.id', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='uncompressed_size', full_name='opencensus.proto.trace.v1.Span.TimeEvent.MessageEvent.uncompressed_size', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='compressed_size', full_name='opencensus.proto.trace.v1.Span.TimeEvent.MessageEvent.compressed_size', index=3,
      number=4, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _SPAN_TIMEEVENT_MESSAGEEVENT_TYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1701,
  serialized_end=1908,
)

_SPAN_TIMEEVENT = _descriptor.Descriptor(
  name='TimeEvent',
  full_name='opencensus.proto.trace.v1.Span.TimeEvent',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='time', full_name='opencensus.proto.trace.v1.Span.TimeEvent.time', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='annotation', full_name='opencensus.proto.trace.v1.Span.TimeEvent.annotation', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='message_event', full_name='opencensus.proto.trace.v1.Span.TimeEvent.message_event', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_SPAN_TIMEEVENT_ANNOTATION, _SPAN_TIMEEVENT_MESSAGEEVENT, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='value', full_name='opencensus.proto.trace.v1.Span.TimeEvent.value',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=1342,
  serialized_end=1917,
)

_SPAN_TIMEEVENTS = _descriptor.Descriptor(
  name='TimeEvents',
  full_name='opencensus.proto.trace.v1.Span.TimeEvents',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='time_event', full_name='opencensus.proto.trace.v1.Span.TimeEvents.time_event', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dropped_annotations_count', full_name='opencensus.proto.trace.v1.Span.TimeEvents.dropped_annotations_count', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dropped_message_events_count', full_name='opencensus.proto.trace.v1.Span.TimeEvents.dropped_message_events_count', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1920,
  serialized_end=2068,
)

_SPAN_LINK = _descriptor.Descriptor(
  name='Link',
  full_name='opencensus.proto.trace.v1.Span.Link',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='trace_id', full_name='opencensus.proto.trace.v1.Span.Link.trace_id', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='span_id', full_name='opencensus.proto.trace.v1.Span.Link.span_id', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type', full_name='opencensus.proto.trace.v1.Span.Link.type', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='attributes', full_name='opencensus.proto.trace.v1.Span.Link.attributes', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tracestate', full_name='opencensus.proto.trace.v1.Span.Link.tracestate', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _SPAN_LINK_TYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2071,
  serialized_end=2374,
)

_SPAN_LINKS = _descriptor.Descriptor(
  name='Links',
  full_name='opencensus.proto.trace.v1.Span.Links',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='link', full_name='opencensus.proto.trace.v1.Span.Links.link', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dropped_links_count', full_name='opencensus.proto.trace.v1.Span.Links.dropped_links_count', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2376,
  serialized_end=2464,
)

_SPAN = _descriptor.Descriptor(
  name='Span',
  full_name='opencensus.proto.trace.v1.Span',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='trace_id', full_name='opencensus.proto.trace.v1.Span.trace_id', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='span_id', full_name='opencensus.proto.trace.v1.Span.span_id', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tracestate', full_name='opencensus.proto.trace.v1.Span.tracestate', index=2,
      number=15, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='parent_span_id', full_name='opencensus.proto.trace.v1.Span.parent_span_id', index=3,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='opencensus.proto.trace.v1.Span.name', index=4,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='kind', full_name='opencensus.proto.trace.v1.Span.kind', index=5,
      number=14, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='start_time', full_name='opencensus.proto.trace.v1.Span.start_time', index=6,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='end_time', full_name='opencensus.proto.trace.v1.Span.end_time', index=7,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='attributes', full_name='opencensus.proto.trace.v1.Span.attributes', index=8,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stack_trace', full_name='opencensus.proto.trace.v1.Span.stack_trace', index=9,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='time_events', full_name='opencensus.proto.trace.v1.Span.time_events', index=10,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='links', full_name='opencensus.proto.trace.v1.Span.links', index=11,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status', full_name='opencensus.proto.trace.v1.Span.status', index=12,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='resource', full_name='opencensus.proto.trace.v1.Span.resource', index=13,
      number=16, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='same_process_as_parent_span', full_name='opencensus.proto.trace.v1.Span.same_process_as_parent_span', index=14,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='child_span_count', full_name='opencensus.proto.trace.v1.Span.child_span_count', index=15,
      number=13, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_SPAN_TRACESTATE, _SPAN_ATTRIBUTES, _SPAN_TIMEEVENT, _SPAN_TIMEEVENTS, _SPAN_LINK, _SPAN_LINKS, ],
  enum_types=[
    _SPAN_SPANKIND,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=179,
  serialized_end=2527,
)


_STATUS = _descriptor.Descriptor(
  name='Status',
  full_name='opencensus.proto.trace.v1.Status',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='code', full_name='opencensus.proto.trace.v1.Status.code', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='message', full_name='opencensus.proto.trace.v1.Status.message', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2529,
  serialized_end=2568,
)


_ATTRIBUTEVALUE = _descriptor.Descriptor(
  name='AttributeValue',
  full_name='opencensus.proto.trace.v1.AttributeValue',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='string_value', full_name='opencensus.proto.trace.v1.AttributeValue.string_value', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='int_value', full_name='opencensus.proto.trace.v1.AttributeValue.int_value', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bool_value', full_name='opencensus.proto.trace.v1.AttributeValue.bool_value', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='double_value', full_name='opencensus.proto.trace.v1.AttributeValue.double_value', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='value', full_name='opencensus.proto.trace.v1.AttributeValue.value',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=2571,
  serialized_end=2733,
)


_STACKTRACE_STACKFRAME = _descriptor.Descriptor(
  name='StackFrame',
  full_name='opencensus.proto.trace.v1.StackTrace.StackFrame',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='function_name', full_name='opencensus.proto.trace.v1.StackTrace.StackFrame.function_name', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='original_function_name', full_name='opencensus.proto.trace.v1.StackTrace.StackFrame.original_function_name', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='file_name', full_name='opencensus.proto.trace.v1.StackTrace.StackFrame.file_name', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='line_number', full_name='opencensus.proto.trace.v1.StackTrace.StackFrame.line_number', index=3,
      number=4, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='column_number', full_name='opencensus.proto.trace.v1.StackTrace.StackFrame.column_number', index=4,
      number=5, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='load_module', full_name='opencensus.proto.trace.v1.StackTrace.StackFrame.load_module', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='source_version', full_name='opencensus.proto.trace.v1.StackTrace.StackFrame.source_version', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2853,
  serialized_end=3247,
)

_STACKTRACE_STACKFRAMES = _descriptor.Descriptor(
  name='StackFrames',
  full_name='opencensus.proto.trace.v1.StackTrace.StackFrames',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='frame', full_name='opencensus.proto.trace.v1.StackTrace.StackFrames.frame', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dropped_frames_count', full_name='opencensus.proto.trace.v1.StackTrace.StackFrames.dropped_frames_count', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3249,
  serialized_end=3357,
)

_STACKTRACE = _descriptor.Descriptor(
  name='StackTrace',
  full_name='opencensus.proto.trace.v1.StackTrace',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='stack_frames', full_name='opencensus.proto.trace.v1.StackTrace.stack_frames', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stack_trace_hash_id', full_name='opencensus.proto.trace.v1.StackTrace.stack_trace_hash_id', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_STACKTRACE_STACKFRAME, _STACKTRACE_STACKFRAMES, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2736,
  serialized_end=3357,
)


_MODULE = _descriptor.Descriptor(
  name='Module',
  full_name='opencensus.proto.trace.v1.Module',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='module', full_name='opencensus.proto.trace.v1.Module.module', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='build_id', full_name='opencensus.proto.trace.v1.Module.build_id', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3360,
  serialized_end=3494,
)


_TRUNCATABLESTRING = _descriptor.Descriptor(
  name='TruncatableString',
  full_name='opencensus.proto.trace.v1.TruncatableString',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='value', full_name='opencensus.proto.trace.v1.TruncatableString.value', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='truncated_byte_count', full_name='opencensus.proto.trace.v1.TruncatableString.truncated_byte_count', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3496,
  serialized_end=3560,
)

_SPAN_TRACESTATE_ENTRY.containing_type = _SPAN_TRACESTATE
_SPAN_TRACESTATE.fields_by_name['entries'].message_type = _SPAN_TRACESTATE_ENTRY
_SPAN_TRACESTATE.containing_type = _SPAN
_SPAN_ATTRIBUTES_ATTRIBUTEMAPENTRY.fields_by_name['value'].message_type = _ATTRIBUTEVALUE
_SPAN_ATTRIBUTES_ATTRIBUTEMAPENTRY.containing_type = _SPAN_ATTRIBUTES
_SPAN_ATTRIBUTES.fields_by_name['attribute_map'].message_type = _SPAN_ATTRIBUTES_ATTRIBUTEMAPENTRY
_SPAN_ATTRIBUTES.containing_type = _SPAN
_SPAN_TIMEEVENT_ANNOTATION.fields_by_name['description'].message_type = _TRUNCATABLESTRING
_SPAN_TIMEEVENT_ANNOTATION.fields_by_name['attributes'].message_type = _SPAN_ATTRIBUTES
_SPAN_TIMEEVENT_ANNOTATION.containing_type = _SPAN_TIMEEVENT
_SPAN_TIMEEVENT_MESSAGEEVENT.fields_by_name['type'].enum_type = _SPAN_TIMEEVENT_MESSAGEEVENT_TYPE
_SPAN_TIMEEVENT_MESSAGEEVENT.containing_type = _SPAN_TIMEEVENT
_SPAN_TIMEEVENT_MESSAGEEVENT_TYPE.containing_type = _SPAN_TIMEEVENT_MESSAGEEVENT
_SPAN_TIMEEVENT.fields_by_name['time'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_SPAN_TIMEEVENT.fields_by_name['annotation'].message_type = _SPAN_TIMEEVENT_ANNOTATION
_SPAN_TIMEEVENT.fields_by_name['message_event'].message_type = _SPAN_TIMEEVENT_MESSAGEEVENT
_SPAN_TIMEEVENT.containing_type = _SPAN
_SPAN_TIMEEVENT.oneofs_by_name['value'].fields.append(
  _SPAN_TIMEEVENT.fields_by_name['annotation'])
_SPAN_TIMEEVENT.fields_by_name['annotation'].containing_oneof = _SPAN_TIMEEVENT.oneofs_by_name['value']
_SPAN_TIMEEVENT.oneofs_by_name['value'].fields.append(
  _SPAN_TIMEEVENT.fields_by_name['message_event'])
_SPAN_TIMEEVENT.fields_by_name['message_event'].containing_oneof = _SPAN_TIMEEVENT.oneofs_by_name['value']
_SPAN_TIMEEVENTS.fields_by_name['time_event'].message_type = _SPAN_TIMEEVENT
_SPAN_TIMEEVENTS.containing_type = _SPAN
_SPAN_LINK.fields_by_name['type'].enum_type = _SPAN_LINK_TYPE
_SPAN_LINK.fields_by_name['attributes'].message_type = _SPAN_ATTRIBUTES
_SPAN_LINK.fields_by_name['tracestate'].message_type = _SPAN_TRACESTATE
_SPAN_LINK.containing_type = _SPAN
_SPAN_LINK_TYPE.containing_type = _SPAN_LINK
_SPAN_LINKS.fields_by_name['link'].message_type = _SPAN_LINK
_SPAN_LINKS.containing_type = _SPAN
_SPAN.fields_by_name['tracestate'].message_type = _SPAN_TRACESTATE
_SPAN.fields_by_name['name'].message_type = _TRUNCATABLESTRING
_SPAN.fields_by_name['kind'].enum_type = _SPAN_SPANKIND
_SPAN.fields_by_name['start_time'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_SPAN.fields_by_name['end_time'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_SPAN.fields_by_name['attributes'].message_type = _SPAN_ATTRIBUTES
_SPAN.fields_by_name['stack_trace'].message_type = _STACKTRACE
_SPAN.fields_by_name['time_events'].message_type = _SPAN_TIMEEVENTS
_SPAN.fields_by_name['links'].message_type = _SPAN_LINKS
_SPAN.fields_by_name['status'].message_type = _STATUS
_SPAN.fields_by_name['resource'].message_type = opencensus_dot_proto_dot_resource_dot_v1_dot_resource__pb2._RESOURCE
_SPAN.fields_by_name['same_process_as_parent_span'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_SPAN.fields_by_name['child_span_count'].message_type = google_dot_protobuf_dot_wrappers__pb2._UINT32VALUE
_SPAN_SPANKIND.containing_type = _SPAN
_ATTRIBUTEVALUE.fields_by_name['string_value'].message_type = _TRUNCATABLESTRING
_ATTRIBUTEVALUE.oneofs_by_name['value'].fields.append(
  _ATTRIBUTEVALUE.fields_by_name['string_value'])
_ATTRIBUTEVALUE.fields_by_name['string_value'].containing_oneof = _ATTRIBUTEVALUE.oneofs_by_name['value']
_ATTRIBUTEVALUE.oneofs_by_name['value'].fields.append(
  _ATTRIBUTEVALUE.fields_by_name['int_value'])
_ATTRIBUTEVALUE.fields_by_name['int_value'].containing_oneof = _ATTRIBUTEVALUE.oneofs_by_name['value']
_ATTRIBUTEVALUE.oneofs_by_name['value'].fields.append(
  _ATTRIBUTEVALUE.fields_by_name['bool_value'])
_ATTRIBUTEVALUE.fields_by_name['bool_value'].containing_oneof = _ATTRIBUTEVALUE.oneofs_by_name['value']
_ATTRIBUTEVALUE.oneofs_by_name['value'].fields.append(
  _ATTRIBUTEVALUE.fields_by_name['double_value'])
_ATTRIBUTEVALUE.fields_by_name['double_value'].containing_oneof = _ATTRIBUTEVALUE.oneofs_by_name['value']
_STACKTRACE_STACKFRAME.fields_by_name['function_name'].message_type = _TRUNCATABLESTRING
_STACKTRACE_STACKFRAME.fields_by_name['original_function_name'].message_type = _TRUNCATABLESTRING
_STACKTRACE_STACKFRAME.fields_by_name['file_name'].message_type = _TRUNCATABLESTRING
_STACKTRACE_STACKFRAME.fields_by_name['load_module'].message_type = _MODULE
_STACKTRACE_STACKFRAME.fields_by_name['source_version'].message_type = _TRUNCATABLESTRING
_STACKTRACE_STACKFRAME.containing_type = _STACKTRACE
_STACKTRACE_STACKFRAMES.fields_by_name['frame'].message_type = _STACKTRACE_STACKFRAME
_STACKTRACE_STACKFRAMES.containing_type = _STACKTRACE
_STACKTRACE.fields_by_name['stack_frames'].message_type = _STACKTRACE_STACKFRAMES
_MODULE.fields_by_name['module'].message_type = _TRUNCATABLESTRING
_MODULE.fields_by_name['build_id'].message_type = _TRUNCATABLESTRING
DESCRIPTOR.message_types_by_name['Span'] = _SPAN
DESCRIPTOR.message_types_by_name['Status'] = _STATUS
DESCRIPTOR.message_types_by_name['AttributeValue'] = _ATTRIBUTEVALUE
DESCRIPTOR.message_types_by_name['StackTrace'] = _STACKTRACE
DESCRIPTOR.message_types_by_name['Module'] = _MODULE
DESCRIPTOR.message_types_by_name['TruncatableString'] = _TRUNCATABLESTRING
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Span = _reflection.GeneratedProtocolMessageType('Span', (_message.Message,), {

  'Tracestate' : _reflection.GeneratedProtocolMessageType('Tracestate', (_message.Message,), {

    'Entry' : _reflection.GeneratedProtocolMessageType('Entry', (_message.Message,), {
      'DESCRIPTOR' : _SPAN_TRACESTATE_ENTRY,
      '__module__' : 'opencensus.proto.trace.v1.trace_pb2'
      # @@protoc_insertion_point(class_scope:opencensus.proto.trace.v1.Span.Tracestate.Entry)
      })
    ,
    'DESCRIPTOR' : _SPAN_TRACESTATE,
    '__module__' : 'opencensus.proto.trace.v1.trace_pb2'
    # @@protoc_insertion_point(class_scope:opencensus.proto.trace.v1.Span.Tracestate)
    })
  ,

  'Attributes' : _reflection.GeneratedProtocolMessageType('Attributes', (_message.Message,), {

    'AttributeMapEntry' : _reflection.GeneratedProtocolMessageType('AttributeMapEntry', (_message.Message,), {
      'DESCRIPTOR' : _SPAN_ATTRIBUTES_ATTRIBUTEMAPENTRY,
      '__module__' : 'opencensus.proto.trace.v1.trace_pb2'
      # @@protoc_insertion_point(class_scope:opencensus.proto.trace.v1.Span.Attributes.AttributeMapEntry)
      })
    ,
    'DESCRIPTOR' : _SPAN_ATTRIBUTES,
    '__module__' : 'opencensus.proto.trace.v1.trace_pb2'
    # @@protoc_insertion_point(class_scope:opencensus.proto.trace.v1.Span.Attributes)
    })
  ,

  'TimeEvent' : _reflection.GeneratedProtocolMessageType('TimeEvent', (_message.Message,), {

    'Annotation' : _reflection.GeneratedProtocolMessageType('Annotation', (_message.Message,), {
      'DESCRIPTOR' : _SPAN_TIMEEVENT_ANNOTATION,
      '__module__' : 'opencensus.proto.trace.v1.trace_pb2'
      # @@protoc_insertion_point(class_scope:opencensus.proto.trace.v1.Span.TimeEvent.Annotation)
      })
    ,

    'MessageEvent' : _reflection.GeneratedProtocolMessageType('MessageEvent', (_message.Message,), {
      'DESCRIPTOR' : _SPAN_TIMEEVENT_MESSAGEEVENT,
      '__module__' : 'opencensus.proto.trace.v1.trace_pb2'
      # @@protoc_insertion_point(class_scope:opencensus.proto.trace.v1.Span.TimeEvent.MessageEvent)
      })
    ,
    'DESCRIPTOR' : _SPAN_TIMEEVENT,
    '__module__' : 'opencensus.proto.trace.v1.trace_pb2'
    # @@protoc_insertion_point(class_scope:opencensus.proto.trace.v1.Span.TimeEvent)
    })
  ,

  'TimeEvents' : _reflection.GeneratedProtocolMessageType('TimeEvents', (_message.Message,), {
    'DESCRIPTOR' : _SPAN_TIMEEVENTS,
    '__module__' : 'opencensus.proto.trace.v1.trace_pb2'
    # @@protoc_insertion_point(class_scope:opencensus.proto.trace.v1.Span.TimeEvents)
    })
  ,

  'Link' : _reflection.GeneratedProtocolMessageType('Link', (_message.Message,), {
    'DESCRIPTOR' : _SPAN_LINK,
    '__module__' : 'opencensus.proto.trace.v1.trace_pb2'
    # @@protoc_insertion_point(class_scope:opencensus.proto.trace.v1.Span.Link)
    })
  ,

  'Links' : _reflection.GeneratedProtocolMessageType('Links', (_message.Message,), {
    'DESCRIPTOR' : _SPAN_LINKS,
    '__module__' : 'opencensus.proto.trace.v1.trace_pb2'
    # @@protoc_insertion_point(class_scope:opencensus.proto.trace.v1.Span.Links)
    })
  ,
  'DESCRIPTOR' : _SPAN,
  '__module__' : 'opencensus.proto.trace.v1.trace_pb2'
  # @@protoc_insertion_point(class_scope:opencensus.proto.trace.v1.Span)
  })
_sym_db.RegisterMessage(Span)
_sym_db.RegisterMessage(Span.Tracestate)
_sym_db.RegisterMessage(Span.Tracestate.Entry)
_sym_db.RegisterMessage(Span.Attributes)
_sym_db.RegisterMessage(Span.Attributes.AttributeMapEntry)
_sym_db.RegisterMessage(Span.TimeEvent)
_sym_db.RegisterMessage(Span.TimeEvent.Annotation)
_sym_db.RegisterMessage(Span.TimeEvent.MessageEvent)
_sym_db.RegisterMessage(Span.TimeEvents)
_sym_db.RegisterMessage(Span.Link)
_sym_db.RegisterMessage(Span.Links)

Status = _reflection.GeneratedProtocolMessageType('Status', (_message.Message,), {
  'DESCRIPTOR' : _STATUS,
  '__module__' : 'opencensus.proto.trace.v1.trace_pb2'
  # @@protoc_insertion_point(class_scope:opencensus.proto.trace.v1.Status)
  })
_sym_db.RegisterMessage(Status)

AttributeValue = _reflection.GeneratedProtocolMessageType('AttributeValue', (_message.Message,), {
  'DESCRIPTOR' : _ATTRIBUTEVALUE,
  '__module__' : 'opencensus.proto.trace.v1.trace_pb2'
  # @@protoc_insertion_point(class_scope:opencensus.proto.trace.v1.AttributeValue)
  })
_sym_db.RegisterMessage(AttributeValue)

StackTrace = _reflection.GeneratedProtocolMessageType('StackTrace', (_message.Message,), {

  'StackFrame' : _reflection.GeneratedProtocolMessageType('StackFrame', (_message.Message,), {
    'DESCRIPTOR' : _STACKTRACE_STACKFRAME,
    '__module__' : 'opencensus.proto.trace.v1.trace_pb2'
    # @@protoc_insertion_point(class_scope:opencensus.proto.trace.v1.StackTrace.StackFrame)
    })
  ,

  'StackFrames' : _reflection.GeneratedProtocolMessageType('StackFrames', (_message.Message,), {
    'DESCRIPTOR' : _STACKTRACE_STACKFRAMES,
    '__module__' : 'opencensus.proto.trace.v1.trace_pb2'
    # @@protoc_insertion_point(class_scope:opencensus.proto.trace.v1.StackTrace.StackFrames)
    })
  ,
  'DESCRIPTOR' : _STACKTRACE,
  '__module__' : 'opencensus.proto.trace.v1.trace_pb2'
  # @@protoc_insertion_point(class_scope:opencensus.proto.trace.v1.StackTrace)
  })
_sym_db.RegisterMessage(StackTrace)
_sym_db.RegisterMessage(StackTrace.StackFrame)
_sym_db.RegisterMessage(StackTrace.StackFrames)

Module = _reflection.GeneratedProtocolMessageType('Module', (_message.Message,), {
  'DESCRIPTOR' : _MODULE,
  '__module__' : 'opencensus.proto.trace.v1.trace_pb2'
  # @@protoc_insertion_point(class_scope:opencensus.proto.trace.v1.Module)
  })
_sym_db.RegisterMessage(Module)

TruncatableString = _reflection.GeneratedProtocolMessageType('TruncatableString', (_message.Message,), {
  'DESCRIPTOR' : _TRUNCATABLESTRING,
  '__module__' : 'opencensus.proto.trace.v1.trace_pb2'
  # @@protoc_insertion_point(class_scope:opencensus.proto.trace.v1.TruncatableString)
  })
_sym_db.RegisterMessage(TruncatableString)


DESCRIPTOR._options = None
_SPAN_ATTRIBUTES_ATTRIBUTEMAPENTRY._options = None
# @@protoc_insertion_point(module_scope)
